@@ -120,18 +120,20 @@ logposterior_exponential_nospat <- function(tm,delta,X,beta,omega,betapriormean,
 ##' @param eta eta vector at which to evaluate the posterior
 ##' @param gamma the transformed latent Gaussian field at which to evaluate the posterior
 ##' @param priors the priors, an object of class mcmcPriors
-##' @param covmodel an object of class covmodel, see ?covmodel
+##' @param cov.model an object of class covmodel, see ?covmodel
 ##' @param u distance matrix
 ##' @param control list of control parameters, see ?inference.control
 ##' @return the log posterior
 ##' @return ...
 ##' @export
 
-logposterior.exp <- function(tm,delta,X,beta,omega,eta,gamma,priors,covmodel,u,control){
+logposterior.exp <- function(tm,delta,X,beta,omega,eta,gamma,priors,cov.model,u,control){
 
     n <- nrow(X)
     Xbeta <- X%*%beta
-    sigma <- matrix(getcov(u=u,sigma=exp(eta[1]),phi=exp(eta[2]),model=covmodel$model,pars=covmodel$pars),n,n)
+    
+    sigma <- matrix(EvalCov(cov.model,u=u,parameters=eta),n,n)
+    
     cholsigma <- t(chol(sigma))
     priorcontrib <- -(1/2)*sum(gamma^2) + do.call(priors$call,args=list(beta=beta,omega=omega,eta=eta,priors=priors))
     Y <- -eta[1]^2/2 + cholsigma%*%gamma
@@ -159,6 +161,8 @@ logposterior.exp <- function(tm,delta,X,beta,omega,eta,gamma,priors,covmodel,u,c
     }   
     
     grad <- grad + deriv
+    
+    #browser()
 
     return(list(logpost=logpost,grad=grad,Y=Y))
 }
@@ -176,19 +180,20 @@ logposterior.exp <- function(tm,delta,X,beta,omega,eta,gamma,priors,covmodel,u,c
 ##' @param eta eta vector at which to evaluate the posterior
 ##' @param gamma the transformed latent Gaussian field at which to evaluate the posterior
 ##' @param priors the priors, an object of class mcmcPriors
-##' @param covmodel an object of class covmodel, see ?covmodel
+##' @param cov.model an object of class covmodel, see ?covmodel
 ##' @param u distance matrix
 ##' @param control list of control parameters, see ?inference.control
 ##' @return the log posterior
 ##' @return ...
 ##' @export
 
-logposterior.exp.gridded <- function(tm,delta,X,beta,omega,eta,gamma,priors,covmodel,u,control){
+logposterior.exp.gridded <- function(tm,delta,X,beta,omega,eta,gamma,priors,cov.model,u,control){
 
     n <- nrow(X)
     Xbeta <- X%*%beta
-
-    covbase <- matrix(getcov(u=u,sigma=exp(eta[1]),phi=exp(eta[2]),model=covmodel$model,pars=covmodel$pars),control$Mext,control$Next)
+        
+    covbase <- matrix(EvalCov(cov.model,u=u,parameters=eta),control$Mext,control$Next)
+    
     invrootQeigs <- sqrt(Re(fft(covbase)))
     
     Ygrid <- YfromGamma(gamma,invrootQeigs=invrootQeigs,mu=-(exp(eta[1]))^2/2)   
@@ -224,6 +229,10 @@ logposterior.exp.gridded <- function(tm,delta,X,beta,omega,eta,gamma,priors,covm
     grad[(lenbeta+lenomega+leneta+1):npars] <- grad[(lenbeta+lenomega+leneta+1):npars] + Re((1/(control$Mext*control$Next))*fft(invrootQeigs*fft(bitsnbobs,inverse=TRUE)))
       
     grad <- grad + deriv
+    
+    #image.plot(control$fftgrid$mcens[1:64],control$fftgrid$ncens[1:64],matrix(grad[-(1:6)],128,128)[1:64,1:64])
+    #points(coords)
+    #browser()
 
     return(list(logpost=logpost,grad=grad,Y=Ygrid))
 }
@@ -242,21 +251,23 @@ logposterior.exp.gridded <- function(tm,delta,X,beta,omega,eta,gamma,priors,covm
 ##' @param eta eta vector at which to evaluate the posterior
 ##' @param gamma the transformed latent Gaussian field at which to evaluate the posterior
 ##' @param priors the priors, an object of class mcmcPriors
-##' @param covmodel an object of class covmodel, see ?covmodel
+##' @param cov.model an object of class covmodel, see ?covmodel
 ##' @param u distance matrix
 ##' @param control list of control parameters, see ?inference.control
 ##' @return the log posterior
 ##' @return ...
 ##' @export
 
-logposterior.weibull <- function(tm,delta,X,beta,omega,eta,gamma,priors,covmodel,u,control){
+logposterior.weibull <- function(tm,delta,X,beta,omega,eta,gamma,priors,cov.model,u,control){
 
     alpha <- exp(omega[1])
     lambda <- exp(omega[2])
 
     n <- nrow(X)
     Xbeta <- X%*%beta
-    sigma <- matrix(getcov(u=u,sigma=exp(eta[1]),phi=exp(eta[2]),model=covmodel$model,pars=covmodel$pars),n,n)
+    
+    sigma <- matrix(EvalCov(cov.model,u=u,parameters=eta),n,n)
+    
     cholsigma <- t(chol(sigma))
     priorcontrib <- -(1/2)*sum(gamma^2) + do.call(priors$call,args=list(beta=beta,omega=omega,eta=eta,priors=priors))
     Y <- -eta[1]^2/2 + cholsigma%*%gamma
@@ -308,14 +319,14 @@ logposterior.weibull <- function(tm,delta,X,beta,omega,eta,gamma,priors,covmodel
 ##' @param eta eta vector at which to evaluate the posterior
 ##' @param gamma the transformed latent Gaussian field at which to evaluate the posterior
 ##' @param priors the priors, an object of class mcmcPriors
-##' @param covmodel an object of class covmodel, see ?covmodel
+##' @param cov.model an object of class covmodel, see ?covmodel
 ##' @param u distance matrix
 ##' @param control list of control parameters, see ?inference.control
 ##' @return the log posterior
 ##' @return ...
 ##' @export
 
-logposterior.weibull.gridded <- function(tm,delta,X,beta,omega,eta,gamma,priors,covmodel,u,control){
+logposterior.weibull.gridded <- function(tm,delta,X,beta,omega,eta,gamma,priors,cov.model,u,control){
 
     alpha <- exp(omega[1])
     lambda <- exp(omega[2])
@@ -323,7 +334,8 @@ logposterior.weibull.gridded <- function(tm,delta,X,beta,omega,eta,gamma,priors,
     n <- nrow(X)
     Xbeta <- X%*%beta
 
-    covbase <- matrix(getcov(u=u,sigma=exp(eta[1]),phi=exp(eta[2]),model=covmodel$model,pars=covmodel$pars),control$Mext,control$Next)
+    covbase <- matrix(EvalCov(cov.model,u=u,parameters=eta),control$Mext,control$Next)    
+    
     invrootQeigs <- sqrt(Re(fft(covbase)))
     
     Ygrid <- YfromGamma(gamma,invrootQeigs=invrootQeigs,mu=-(exp(eta[1]))^2/2)   
