@@ -9,7 +9,7 @@
 ##' @param theta parameter for the baseline hazard model (the rate for exponential data and the shape and scale for Weibull data)
 ##' @param dist the distribution choice: exp or weibull at present
 ##' @param coords matrix with 2 columns giving the coordinates at which to simulate data
-##' @param sigmaphi a vector of length 2: the parameters for the covariance function, sigma and phi in that order
+##' @param cov.parameters a vector: the parameters for the covariance function
 ##' @param cov.model an object of class covmodel, see ?covmodel
 ##' @param mcmc.control mcmc control paramters, see ?mcmcpars
 ##' @param savechains save all chains? runs faster if set to FALSE, but then you'll be unable to conduct convergence/mixing diagnostics
@@ -22,7 +22,7 @@ simsurv <- function(X=cbind(age=runif(100,5,50),sex=rbinom(100,1,0.5),cancer=rbi
                             theta=1,
                             dist="exp",
                             coords=matrix(runif(2*nrow(X)),nrow(X),2),
-                            sigmaphi=c(1,0.1),
+                            cov.parameters=c(1,0.1),
                             cov.model=covmodel(model="exponential",pars=NULL),
                             mcmc.control=mcmcpars(nits=100000,burn=10000,thin=90),      
                             savechains=TRUE){
@@ -33,10 +33,12 @@ simsurv <- function(X=cbind(age=runif(100,5,50),sex=rbinom(100,1,0.5),cancer=rbi
 
     n <- nrow(X)
     u <- as.vector(distmat)
+
+    transpars <- sapply(1:length(cov.parameters),function(i){cov.model$trans[[i]](cov.parameters[i])})
+    sigma <- matrix(EvalCov(cov.model,u=u,parameters=transpars),n,n) # note that the parameters are back transformed in the call to EvalCov  
     
-    sigma <- matrix(getcov(u=u,sigma=sigmaphi[1],phi=sigmaphi[2],model=cov.model$model,pars=cov.model$pars),n,n)
     sigmachol <- t(chol(sigma))
-    Y <- -sigmaphi[1]^2/2+sigmachol%*%rnorm(n)
+    Y <- -cov.parameters[which(cov.model$parnames=="sigma")]^2/2 + sigmachol%*%rnorm(n)
     expY <- exp(Y)  
  
     XbetaplusY <- X%*%beta + Y
@@ -104,5 +106,5 @@ simsurv <- function(X=cbind(age=runif(100,5,50),sex=rbinom(100,1,0.5),cancer=rbi
     
     cat("Mean acceptance:",mean(acrec),"\n")
     
-    return(list(X=X,T=T,survtimes=tchoice,theta=theta,beta=beta,tarrec=tarrec,n=n,Y=Y,dist=dist,coords=coords,sigmaphi=sigmaphi,distmat=distmat,u=u))
+    return(list(X=X,T=T,survtimes=tchoice,theta=theta,beta=beta,tarrec=tarrec,n=n,Y=Y,dist=dist,coords=coords,cov.parameters=cov.parameters,distmat=distmat,u=u))
 }
\ No newline at end of file
